@@ -610,7 +610,10 @@ case "$sbcl_os" in
                 ;;
             openbsd)
                 printf ' :openbsd' >> $ltf
-                printf ' :gcc-tls' >> $ltf
+                case "$sbcl_arch" in
+                  arm64 | x86 | x86-64)
+                  	printf ' :gcc-tls' >> $ltf
+                esac
                 link_or_copy Config.$sbcl_arch-openbsd Config
                 ;;
             netbsd)
@@ -629,10 +632,15 @@ case "$sbcl_os" in
         ;;
     darwin)
         printf ' :unix :bsd :darwin :mach-o' >> $ltf
+        darwin_version=`uname -r`
+        darwin_version_major=${DARWIN_VERSION_MAJOR:-${darwin_version%%.*}}
+        if (( 10 > $darwin_version_major )) || [ $sbcl_arch = "ppc" ]; then
+            printf ' :use-darwin-posix-semaphores :avoid-pthread-setname-np' >> $ltf
+        fi
+        if (( 15 > $darwin_version_major )); then
+            printf ' :avoid-clock-gettime' >> $ltf
+        fi
         if [ $sbcl_arch = "x86-64" ]; then
-            darwin_version=`uname -r`
-            darwin_version_major=${DARWIN_VERSION_MAJOR:-${darwin_version%%.*}}
-
             if (( 8 < $darwin_version_major )); then
 	        printf ' :inode64' >> $ltf
             fi
@@ -676,20 +684,6 @@ case "$sbcl_os" in
 esac
 cd "$original_dir"
 
-# FIXME: Things like :c-stack-grows-..., etc, should be
-# *derived-target-features* or equivalent, so that there was a nicer
-# way to specify them then sprinkling them in this file. They should
-# still be tweakable by advanced users, though, but probably not
-# appear in *features* of target. #+/- should be adjusted to take
-# them in account as well. At minimum the nicer specification stuff,
-# though:
-#
-# (define-feature :dlopen (features)
-#   (union '(:bsd :linux :darwin :sunos) features))
-#
-# (define-feature :c-stack-grows-downwards-not-upwards (features)
-#   (member :x86 features))
-
 if $android
 then
     . tools-for-build/android_run.sh
@@ -697,10 +691,6 @@ fi
 
 case "$sbcl_arch" in
   x86)
-    if [ "$sbcl_os" = "darwin" ]; then
-        echo "Unsupported configuration"
-        exit 1
-    fi
     if [ "$sbcl_os" = "win32" ]; then
         # of course it doesn't provide dlopen, but there is
         # roughly-equivalent magic nevertheless.
@@ -740,8 +730,15 @@ case "$sbcl_arch" in
 	$GNUMAKE -C tools-for-build where-is-mcontext -I ../src/runtime
 	tools-for-build/where-is-mcontext > src/runtime/ppc-linux-mcontext.h || (echo "error running where-is-mcontext"; exit 1)
     elif [ "$sbcl_os" = "darwin" ]; then
-	echo "Unsupported configuration"
-	exit 1
+        # We provide a dlopen shim, so a little lie won't hurt
+ 	printf ' :os-provides-dlopen' >> $ltf
+        # The default stack ulimit under darwin is too small to run PURIFY.
+        # Best we can do is complain and exit at this stage
+        if [ "`ulimit -s`" = "512" ]; then
+            echo "Your stack size limit is too small to build SBCL."
+            echo "See the limit(1) or ulimit(1) commands and the README file."
+            exit 1
+        fi
     fi
     ;;
   ppc64)
