@@ -46,8 +46,10 @@ rm -fr sandbox/scratch
  (append #+win32 (list "EXP.ERROR.7"
                        "EXPT.ERROR.4" "EXPT.ERROR.5" "EXPT.ERROR.6" "EXPT.ERROR.7"
                        "PROBE-FILE.4")
-         #+arm64 (list "EXP.ERROR.4" "EXP.ERROR.5" "EXP.ERROR.6" "EXP.ERROR.7" "EXPT.ERROR.4"
-                       "EXPT.ERROR.5" "EXPT.ERROR.6" "EXPT.ERROR.7")
+         #+x86 (list "CIS.4")
+         #+(and arm64 (not darwin))
+           (list "EXP.ERROR.4" "EXP.ERROR.5" "EXP.ERROR.6" "EXP.ERROR.7" "EXPT.ERROR.4"
+                 "EXPT.ERROR.5" "EXPT.ERROR.6" "EXPT.ERROR.7")
          #-sb-unicode (list "MISC.638")
          (if (member :sb-fasteval sb-impl:+internal-features+)
              (list "INTERSECTION.FOLD.1" "UNION.FOLD.1" "SET-DIFFERENCE.FOLD.1"
