@@ -339,3 +339,45 @@
      (declare (integer x))
      (* x 5))
    (or (integer 5) (integer * -5) (integer 0 0))))
+
+(with-test (:name :truncate-transform-unused-result)
+  (assert-type
+   (lambda (c)
+     (declare ((integer -1000 0) c)
+              (optimize speed))
+     (values
+      (truncate (truncate (rem c -89) -16) 20)))
+   (or (integer 0 0))))
+
+(with-test (:name :rem^2)
+  (checked-compile-and-assert
+   ()
+   `(lambda (a)
+      (declare (fixnum a))
+      (rem a 2))
+   ((-2) 0)
+   ((-3) -1)
+   ((2) 0)
+   ((3) 1)))
+
+(with-test (:name :deposit-field-derive-type)
+  (assert-type
+   (lambda (s)
+     (declare ((member 8 10) s))
+     (deposit-field -21031455 (byte s 9) 1565832649825))
+   (or (integer 1565832320097 1565832320097) (integer 1565832713313 1565832713313))))
+
+(with-test (:name :logior-negative-bound)
+  (checked-compile-and-assert
+   ()
+   `(lambda (b c)
+      (declare ((integer 7703 1903468060) c))
+      (logandc1 (/ (logorc2 c b) -1) c))
+   ((-1 7703) 7702)))
+
+(with-test (:name :set-numeric-contagion)
+  (assert-type
+   (lambda (n)
+     (loop for i below n
+           sum (coerce n 'single-float)))
+   (or (integer 0 0) single-float)))
