@@ -62,17 +62,16 @@
 (defun ir1-named-calls (lambda-expression &optional (full t))
   (let* ((calls)
          (compiled-fun
-          (inspect-ir
-           lambda-expression
-           (lambda (component)
-             (do-blocks (block component)
-               (do-nodes (node nil block)
-                 (when (and (sb-c::basic-combination-p node)
-                            (if full
-                                (eq (sb-c::basic-combination-info node) :full)
-                                t))
-                   (pushnew (sb-c::combination-fun-debug-name node)
-                            calls :test 'equal))))))))
+           (inspect-ir
+            lambda-expression
+            (lambda (component)
+              (do-blocks (block component)
+                (do-nodes (node nil block)
+                  (when (and (sb-c::basic-combination-p node)
+                             (if full
+                                 (eq (sb-c::basic-combination-info node) :full)
+                                 t))
+                    (push (sb-c::combination-fun-debug-name node) calls))))))))
     (values calls compiled-fun)))
 
 ;;; For any call that passes a global constant funarg - as in (FOO #'EQ) -
@@ -146,12 +145,14 @@
       (collect-consing-stats thunk times)
     (let* ((consed-bytes (- after before))
            (bytes-per-iteration (float (/ consed-bytes times))))
-      (assert (funcall (if yes/no #'not #'identity)
-                       ;; If allocation really happened, it can't have been less than one cons cell
-                       ;; per iteration (unless the test is nondeterministic - but in that case
-                       ;; we can't really use this strategy anyway). So consider it to have consed
-                       ;; nothing if the fraction is too small.
-                       (< bytes-per-iteration (* 2 sb-vm:n-word-bytes)))
+      (assert (progn
+                (funcall (if yes/no #'not #'identity)
+                         ;; If allocation really happened, it can't have been less than one cons cell
+                         ;; per iteration (unless the test is nondeterministic - but in that case
+                         ;; we can't really use this strategy anyway). So consider it to have consed
+                         ;; nothing if the fraction is too small.
+                         (< bytes-per-iteration (* 2 sb-vm:n-word-bytes)))
+                #+gc-stress t)
               ()
               "~@<Expected the form ~
                       ~4I~@:_~A ~0I~@:_~
