@@ -570,17 +570,22 @@
   (terpri s)
   (write-string "(defun dumped-huge-manyraw () '#.(make-huge-manyraw))" s)
   (write-string "(defun dumped-hugest-manyraw () '#.(make-hugest-manyraw))" s))
-(defvar *tempfasl* (compile-file *tempfile*))
-(delete-file *tempfile*)
+(defvar *tempfasl*)
+(with-test (:name :compile-huge-manyraw
+            :skipped-on :gc-stress)
+  (setf *tempfasl* (compile-file *tempfile*))
+  (delete-file *tempfile*)
 
-;;; nuke the objects and try another GC just to be extra careful
-(setf *manyraw* nil)
-(sb-ext:gc :full t)
+  ;; nuke the objects and try another GC just to be extra careful
+  (setf *manyraw* nil)
+  (sb-ext:gc :full t)
 
-;;; re-read the dumped structures and check them
-(load *tempfasl*)
-(delete-file *tempfasl*)
-(with-test (:name (:defstruct-raw-slot load))
+  ;; re-read the dumped structures and check them
+  (load *tempfasl*)
+  (delete-file *tempfasl*))
+
+(with-test (:name (:defstruct-raw-slot load)
+                  :skipped-on :gc-stress)
   (check-manyraws (dumped-manyraws))
   (check-huge-manyraw (make-huge-manyraw))
   (assert (equalp (make-huge-manyraw) (dumped-huge-manyraw)))
@@ -1453,7 +1458,6 @@ redefinition."
 (defstruct (badbuf (:constructor make-badbuf ()))
   (str (make-string 128) :type (simple-array character (128))))
 
-;; STR slot gets a type-check in the constructor. It should not
-(test-util:with-test (:name :make-string-type-inference :fails-on :sbcl)
+(test-util:with-test (:name :make-string-type-inference)
   (let ((things (ctu:find-code-constants #'make-badbuf :type 'list)))
     (assert (not things))))
