@@ -40,9 +40,10 @@
   ;; hashes.
   (let ((win 0) (n-trials 10) (prev (sb-int:address-based-counter-val)))
     (dotimes (i n-trials)
-      (declare (notinline cons sb-sys:int-sap)) ; it's flushable, but don't flush it
-      #+use-cons-region (sb-sys:int-sap #xf00fa) ; 2 words in mixed-region
-      #-use-cons-region (cons 1 2)
+      (locally
+          (declare (notinline cons sb-sys:int-sap)) ; it's flushable, but don't flush it
+        #+use-cons-region (sb-sys:int-sap #xf00fa) ; 2 words in mixed-region
+        #-use-cons-region (cons 1 2))
       (let ((ptr (sb-int:address-based-counter-val)))
         (when (= ptr (1+ prev))
           (incf win))
@@ -267,7 +268,8 @@
 ;;; which has two different freelists - one of cells that REMHASH has made available
 ;;; and one of cells that GC has marked as empty. Since we no longer inhibit GC
 ;;; during table operations, we need to give GC a list of its own to manipulate.
-(with-test (:name (hash-table :gc-smashed-cell-list))
+(with-test (:name (hash-table :gc-smashed-cell-list)
+                  :broken-on :mark-region-gc)
   (flet ((f ()
            (dotimes (i 20000) (setf (gethash i *tbl*) (- i)))
            (setf (gethash (cons 1 2) *tbl*) 'foolz)
@@ -498,7 +500,7 @@
     (loop repeat (the fixnum n-iter)
           do
        (let* ((n (random limit random-state))
-              (lisp-hash (sb-impl:murmur-fmix-word-for-unit-test n))
+              (lisp-hash (sb-impl::murmur3-fmix-word n))
               (c-hash (c-murmur-fmix n)))
          (assert (= lisp-hash c-hash))))))
 (compile 'murmur-compare)
