@@ -31,11 +31,11 @@
   (alien-funcall (extern-alien "gc_private_free" (function void unsigned))
                  list))
 
-#+gencgc
 (progn
+(defun page-words-used (index)
+  (ash (slot (deref sb-vm::page-table index) 'sb-vm::words-used*) -1))
 (defun page-need-to-zero (index)
-  (logbitp #+little-endian 6 #+big-endian 1
-           (slot (deref sb-vm::page-table index) 'sb-vm::flags)))
+  (oddp (slot (deref sb-vm::page-table index) 'sb-vm::words-used*)))
 (defun test-private-consing ()
   (let ((conses-per-page ; subtract one for the page header cons
          (1- (/ sb-vm:gencgc-page-bytes (* 2 sb-vm:n-word-bytes))))
@@ -51,7 +51,7 @@
         (push index pages)
         (assert (= cons (+ base-address (* 2 sb-vm:n-word-bytes))))
         ;; words-used should be 4, for 2 conses,
-        (assert (= (slot (deref sb-vm::page-table index) 'sb-vm::words-used) 4))
+        (assert (= (page-words-used index) 4))
         (dotimes (i (1- conses-per-page))
           (setq final (private-list (incf counter))))
         (assert (= final (+ base-address sb-vm:gencgc-page-bytes
@@ -70,34 +70,7 @@
     ;; Each of the pages should have zero words used and need-to-zero = 1
     (dolist (index pages)
       (assert (page-need-to-zero index))
-      (assert (= (slot (deref sb-vm::page-table index) 'sb-vm::words-used) 0))))))
-
-#-gencgc
-(defun test-private-consing ()
-  (let ((conses-per-chunk ; subtract one for the chunk header cons
-         (1- (/ 4096 (* 2 sb-vm:n-word-bytes)))) ; 4096 = CHUNKSIZE
-        (counter 0)
-        (chain))
-    (dotimes (i 5) ; 5 = number of times to invoke malloc()
-      (push nil chain)
-      ;; Use up the chunk, which happens in descending address order.
-      ;; So the last cons allocated is nearest the head of the chunk.
-      (dotimes (i conses-per-chunk)
-        (let ((list (private-list (incf counter))))
-          (setf (car chain) list)))
-      ;; The malloc() result was 1 cons below the lowest cons
-      ;; return by the suballocator.
-      (decf (car chain) (* 2 sb-vm:n-word-bytes)))
-    ;; Test that there are 5 chunks on which to invoke free()
-    (let ((len 0))
-      (loop (unless chain (return))
-            (assert (= (sb-sys:sap-ref-word (sb-sys:int-sap (car chain))
-                                            sb-vm:n-word-bytes)
-                       (or (cadr chain) 0)))
-            (incf len)
-            (pop chain))
-      (assert (= len 5))))
-  (alien-funcall (extern-alien "gc_dispose_private_pages" (function void))))
+      (assert (= (page-words-used index) 0))))))
 
 ;;; These tests disable GC because the private cons allocator
 ;;; assumes exclusive use of the page table, and moreover if GC
