@@ -1140,7 +1140,8 @@
 ;;; one per item. It is still suboptimal in that it can not discern
 ;;; between initializing and updating, so it always uses a :QWORD move
 ;;; despite the prezeroed pages.
-(with-test (:name :init-vector-mov-to-mem)
+(with-test (:name :init-vector-mov-to-mem
+            :skipped-on :debug-gc-barriers)
   (let* ((lines (disassembly-lines
                  '(lambda () (vector #\x 1 2 3))))
          (magic-value
@@ -1281,10 +1282,10 @@
   ;; This is a trivial test of the control case for :stack-instance-set
   (let ((vops-with-barrier
          (find-gc-barriers
-          '(lambda ()
+          '(lambda (x)
             (declare (inline make-wordpair))
             (let ((pair (make-wordpair :a 'foo)))
-              (setf (wordpair-b pair) "hi")
+              (setf (wordpair-b pair) (car x))
               (values (func pair)))))))
     (assert (equal vops-with-barrier '("INSTANCE-INDEX-SET")))))
 
@@ -1375,3 +1376,14 @@
                (setf (car x) y)
                x)))))
     (assert (not vops-with-barrier))))
+
+(with-test (:name :smaller-than-qword-cons-slot-init
+                  :skipped-on (:not :mark-region-gc))
+  (let ((lines (disassembly-lines
+                (compile nil '(lambda (a) (list 1 a #\a))))))
+    (assert (loop for line in lines
+                  thereis (search "MOV BYTE PTR" line))) ; constant 1
+    (assert (loop for line in lines
+                  thereis (search "MOV WORD PTR" line))) ; constant #\a
+    (assert (loop for line in lines
+                  thereis (search "MOV DWORD PTR" line))))) ; constant NIL
